
# Change Log
All notable changes to this project will be documented in this file.
 
The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).



## [0.0.3]

 * selections feature
  
## [0.0.2]

 * sphinx documentation
 * Adding actions routes
 * increase README.md example and documentation
 * Improving selectors with Ref and RefLists
 * Habilitation in Blueprint
 * Using stricto 0.0.8
 * current_user available
 * meta routes with documentation
 * checking routes
  
## [0.0.1]

First version

### Added

### Changed

### Fixed
